% This program is modified by Junyi Liang to estimate the Q10s of different
% soil carbon pools among which there are transfers
% model uses MCMC with initial C pool size

% 04/10/2013

clear all;
close all;
format long e;
  
% random seed is the clock, clock is used because the time we start something is relatively random
RandSeed=clock;          
rand('seed',RandSeed(6));  % seed is the first number to start the generator

Nt      =   36; % number of data points
HS = 2000
HH = 50
QC = 2500
nsim    = 50000;      % number of simulations
ctotal = 37.1;         % initial C pool size, in mg C g-1 dry soil 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 

%****** prior values (c) and parameter ranges (cmin, cmax) ******************
%        f1            f2              parameter names 
a    =  [0.05         0.75]';   
amin =  [0.00         0.00];    
amax =  [0.15         0.20];
%        T1k1         T1k2          T1k3
b    =  [0.010      0.001000      0.000020]';
bmin =  [0.001      0.00010      0.000000];
bmax =  [0.050      0.008000      0.000200];
%       f2,1         f3,1         f1,2       f3,2        f1,3
c    =  [0.5        0.004         0.4        0.03        0.4]';
cmin =  [0.1        0.000         0.1        0.00        0.0]; 
cmax =  [0.6        0.010         0.6        0.03        1.0];
%      Q10(p1)      Q10(p2)       Q10(p3)      
d    =  [2             3            3]';   
dmin =  [0             0            0];    
dmax =  [3             6            6];

%*********** read in data ***************
data = resp (Nt);
day = data(:,1);              % assign columns to values    
temp1 = data(:,2);      % in Kelvin    
temp2 = data(:,3);
resp1 = data(:,4);             % daily values, in mg CO2-C g-1 soil
resp2 = data(:,5);  
stdev1 = 0.191865349226712;
stdev2 = 0.0938292369190862;

%simulation starts
adif  = (amax-amin)';
bdif  = (bmax-bmin)';
cdif = (cmax-cmin)';
ddif = (dmax-dmin)';

a_op=amin'+rand*adif;
a_new=zeros(2,1);      % create a new array with zeros  
b_op=bmin'+rand*bdif;
J_last = 300000;
b_new=zeros(3,1);      % create a new array with zeros  
record_index=1;
c_op=cmin'+rand*cdif;
c_new=zeros(5,1);
d_op=dmin'+rand*ddif;
d_new=zeros(3,1);
DJ1=2*stdev1^2;
DJ2=2*stdev2^2;

%Simulation starts
upgraded=0;
R=8.314;    % universal gas constant

for simu=1:nsim
    counter=simu
    upgraded % shows the upgraded number
    %%%%%%%c_new=Generate_2_k(c_op,cmin,cmax);  %generate a new point
    
    a_new=Generate_a (a_op,amin, amax);
    b_new=Generate_b (b_op,bmin, bmax);
    c_new=Generate_c (c_op,cmin, cmax);
    d_new=Generate_d (d_op,dmin, dmax);
    
    f1 = a_new(1);              %fraction of inital total carbon to Pool 1 at temperature 1
    f2 = a_new(2);              %fraction of inital total carbon to Pool 2 at temperature 1
    f3 = 1-f1-f2;           %fraction of inital total carbon to Pool 3 at temperature 1
    k1 = b_new(1);
    k2 = b_new(2);
    k3 = b_new(3);
    f21 = c_new(1);         %fraction from pool 1 to pool 2 at temperature 1
    f31 = c_new(2);         %fraction from pool 1 to pool 3 at temperature 1
    f12 = c_new(3);         %fraction from pool 2 to pool 1 at temperature 1
    f32 = c_new(4);         %fraction from pool 2 to pool 3 at temperature 1
    f13 = c_new(5);         %fraction from pool 3 to pool 1 at temperature 1
    Q1 = d_new(1);   
    Q2 = d_new(2);
    Q3 = d_new(3);
   
    T1P1 = zeros(day(Nt),1);
    T1P2 = zeros(day(Nt),1);
    T1P3 = zeros(day(Nt),1);
    T1R1 = zeros(day(Nt),1);
    T1R2 = zeros(day(Nt),1);
    T1R3 = zeros(day(Nt),1);
    T1C1 = zeros(day(Nt),1);
    T1C2 = zeros(day(Nt),1);
    T1C3 = zeros(day(Nt),1);
    T1fR1 = zeros(day(Nt),1);
    T1fR2 = zeros(day(Nt),1);
    T1fR3 = zeros(day(Nt),1);
    resp_mod1 = zeros(day(Nt),1);
    
    T2P1 = zeros(day(Nt),1);
    T2P2 = zeros(day(Nt),1);
    T2P3 = zeros(day(Nt),1);
    T2R1 = zeros(day(Nt),1);
    T2R2 = zeros(day(Nt),1);
    T2R3 = zeros(day(Nt),1);
    T2C1 = zeros(day(Nt),1);
    T2C2 = zeros(day(Nt),1);
    T2C3 = zeros(day(Nt),1);
    T2fR1 = zeros(day(Nt),1);
    T2fR2 = zeros(day(Nt),1);
    T2fR3 = zeros(day(Nt),1);
    resp_mod2 = zeros(day(Nt),1);
    
    
    for i = 1
       T1P1(i) = f1*ctotal-k1*f1*ctotal+f12*k2*f2*ctotal+f13*k3*f3*ctotal;
       T1P2(i) = f2*ctotal-k2*f2*ctotal+f21*k1*f1*ctotal;
       T1P3(i) = f3*ctotal-k3*f3*ctotal+f31*k1*f1*ctotal+f32*k2*f2*ctotal;
       
       T1R1(i) = (1-f21-f31)*k1*f1*ctotal;       %respiration rate of pool1 
       T1R2(i) = (1-f12-f32)*k2*f2*ctotal;       %respiration rate of pool2 
       T1R3(i) = (1-f13)*k3*f3*ctotal;           %respiration rate of pool3
       
       T1C1(i) = T1R1(i);
       T1C2(i) = T1R2(i);
       T1C3(i) = T1R3(i);
       
       T1fR1(i) = T1R1(i)/(T1R1(i)+T1R2(i)+T1R3(i));   % proportion of R1 in Rtotal
       T1fR2(i) = T1R2(i)/(T1R1(i)+T1R2(i)+T1R3(i));   % proportion of R2 in Rtotal
       T1fR3(i) = T1R3(i)/(T1R1(i)+T1R2(i)+T1R3(i));   % proportion of R3 in Rtotal

       
       resp_mod1(i) = T1C1(i)+T1C2(i)+T1C3(i);
       
       
       T2P1(i) = f1*ctotal-Q1*k1*f1*ctotal+f12*Q2*k2*f2*ctotal+f13*Q3*k3*f3*ctotal;
       T2P2(i) = f2*ctotal-Q2*k2*f2*ctotal+f21*Q1*k1*f1*ctotal;
       T2P3(i) = f3*ctotal-Q3*k3*f3*ctotal+f31*Q1*k1*f1*ctotal+f32*Q2*k2*f2*ctotal;
       
       T2R1(i) = (1-f21-f31)*Q1*k1*f1*ctotal;       %respiration rate of pool1 
       T2R2(i) = (1-f12-f32)*Q2*k2*f2*ctotal;       %respiration rate of pool2 
       T2R3(i) = (1-f13)*Q1*k3*f3*ctotal;           %respiration rate of pool3
       
       T2C1(i) = T2R1(i);
       T2C2(i) = T2R2(i);
       T2C3(i) = T2R3(i);
       
       T2fR1(i) = T2R1(i)/(T2R1(i)+T2R2(i)+T2R3(i));   % proportion of R1 in Rtotal
       T2fR2(i) = T2R2(i)/(T2R1(i)+T2R2(i)+T2R3(i));   % proportion of R2 in Rtotal
       T2fR3(i) = T2R3(i)/(T2R1(i)+T2R2(i)+T2R3(i));   % proportion of R3 in Rtotal

       
       resp_mod2(i) = T2C1(i)+T2C2(i)+T2C3(i);
        
    end
    
    for i = 2:day(Nt)
        
       T1P1(i) = T1P1(i-1)-k1*T1P1(i-1)+f12*k2*T1P2(i-1)+f13*k3*T1P3(i-1);
       T1P2(i) = T1P2(i-1)-k2*T1P2(i-1)+f21*k1*T1P1(i-1);
       T1P3(i) = T1P3(i-1)-k3*T1P3(i-1)+f31*k1*T1P1(i-1)+f32*k2*T1P2(i-1);
       
       T1R1(i) = (1-f21-f31)*k1*T1P1(i-1);       %respiration rate of pool1 
       T1R2(i) = (1-f12-f32)*k2*T1P2(i-1);       %respiration rate of pool2 
       T1R3(i) = (1-f13)*k3*T1P3(i-1);           %respiration rate of pool3
       
       T1C1(i) = T1C1(i-1)+T1R1(i);                %cummulative carbon respired from pool1
       T1C2(i) = T1C2(i-1)+T1R2(i);                %cummulative carbon respired from pool2
       T1C3(i) = T1C3(i-1)+T1R3(i);                %cummulative carbon respired from pool3
       
       T1fR1(i) = T1R1(i)/(T1R1(i)+T1R2(i)+T1R3(i));   % proportion of R1 in Rtotal
       T1fR2(i) = T1R2(i)/(T1R1(i)+T1R2(i)+T1R3(i));   % proportion of R2 in Rtotal
       T1fR3(i) = T1R3(i)/(T1R1(i)+T1R2(i)+T1R3(i));   % proportion of R3 in Rtotal
       
       resp_mod1(i) = T1C1(i)+T1C2(i)+T1C3(i);
       
       T2P1(i) = T2P1(i-1)-Q1*k1*T2P1(i-1)+f12*Q2*k2*T2P2(i-1)+f13*Q3*k3*T2P3(i-1);
       T2P2(i) = T2P2(i-1)-Q2*k2*T2P2(i-1)+f21*Q1*k1*T2P1(i-1);
       T2P3(i) = T2P3(i-1)-Q3*k3*T2P3(i-1)+f31*Q1*k1*T2P1(i-1)+f32*Q2*k2*T2P2(i-1);
       
       T2R1(i) = (1-f21-f31)*Q1*k1*T2P1(i-1);       %respiration rate of pool1 
       T2R2(i) = (1-f12-f32)*Q2*k2*T2P2(i-1);       %respiration rate of pool2 
       T2R3(i) = (1-f13)*Q3*k3*T2P3(i-1);           %respiration rate of pool3
       
       T2C1(i) = T2C1(i-1)+T2R1(i);                %cummulative carbon respired from pool1
       T2C2(i) = T2C2(i-1)+T2R2(i);                %cummulative carbon respired from pool2
       T2C3(i) = T2C3(i-1)+T2R3(i);                %cummulative carbon respired from pool3
       
       T2fR1(i) = T2R1(i)/(T2R1(i)+T2R2(i)+T2R3(i));   % proportion of R1 in Rtotal
       T2fR2(i) = T2R2(i)/(T2R1(i)+T2R2(i)+T2R3(i));   % proportion of R2 in Rtotal
       T2fR3(i) = T2R3(i)/(T2R1(i)+T2R2(i)+T2R3(i));   % proportion of R3 in Rtotal
       
       resp_mod2(i) = T2C1(i)+T2C2(i)+T2C3(i);
       
    end
    
    T1p1 = zeros(Nt,1);
    T1p2 = zeros(Nt,1);
    T1p3 = zeros(Nt,1);
    T1r1 = zeros(Nt,1);
    T1r2 = zeros(Nt,1);
    T1r3 = zeros(Nt,1);
    T1c1 = zeros(Nt,1);
    T1c2 = zeros(Nt,1);
    T1c3 = zeros(Nt,1);
    T1fr1 = zeros(Nt,1);
    T1fr2 = zeros(Nt,1);
    T1fr3 = zeros(Nt,1);
    CC_mod1 = zeros(Nt,1);
    
    T2p1 = zeros(Nt,1);
    T2p2 = zeros(Nt,1);
    T2p3 = zeros(Nt,1);
    T2r1 = zeros(Nt,1);
    T2r2 = zeros(Nt,1);
    T2r3 = zeros(Nt,1);
    T2c1 = zeros(Nt,1);
    T2c2 = zeros(Nt,1);
    T2c3 = zeros(Nt,1);
    T2fr1 = zeros(Nt,1);
    T2fr2 = zeros(Nt,1);
    T2fr3 = zeros(Nt,1);
    CC_mod2 = zeros(Nt,1);
    
    for m = 1:Nt
        i = day(m);
        
        T1p1(m)=T1P1(i);
        T1p2(m)=T1P2(i);
        T1p3(m)=T1P3(i);
        
        T1r1(m)=T1R1(i);
        T1r2(m)=T1R2(i);
        T1r3(m)=T1R3(i);
        
        T1c1(m)=T1C1(i);
        T1c2(m)=T1C2(i);
        T1c3(m)=T1C3(i);
        
        T1fr1(m)=T1fR1(i);
        T1fr2(m)=T1fR2(i);
        T1fr3(m)=T1fR3(i);
        
        CC_mod1(m) = resp_mod1(i);
        
        T2p1(m)=T2P1(i);
        T2p2(m)=T2P2(i);
        T2p3(m)=T2P3(i);
        
        T2r1(m)=T2R1(i);
        T2r2(m)=T2R2(i);
        T2r3(m)=T2R3(i);
        
        T2c1(m)=T2C1(i);
        T2c2(m)=T2C2(i);
        T2c3(m)=T2C3(i);
        
        T2fr1(m)=T2fR1(i);
        T2fr2(m)=T2fR2(i);
        T2fr3(m)=T2fR3(i);
        
        CC_mod2(m) = resp_mod2(i);
        
    end
    
    % calculate cost function 
    J1  =   (norm(CC_mod1' - resp1'))^2;
    J2  =   (norm(CC_mod2' - resp2'))^2;    % data model error
    J_new= J1/DJ1+J2/DJ2;
    delta_J = J_new-J_last;
	
	if min(1, exp(-delta_J)) >rand
        a_op=a_new;
        b_op=b_new;
        c_op=c_new;
        d_op=d_new;
        J_last=J_new;
        upgraded=upgraded+1;
        a_upgraded(:,upgraded)=a_op;  
        b_upgraded(:,upgraded)=b_op;  
        c_upgraded(:,upgraded)=c_op;
        d_upgraded(:,upgraded)=d_op;
        
        T1CC_record(:,upgraded)=CC_mod1;
        T1P1_record(:,upgraded)=T1p1;
        T1P2_record(:,upgraded)=T1p2;
        T1P3_record(:,upgraded)=T1p3;
        T1R1_record(:,upgraded)=T1r1;
        T1R2_record(:,upgraded)=T1r2;
        T1R3_record(:,upgraded)=T1r3;
        T1C1_record(:,upgraded)=T1c1;
        T1C2_record(:,upgraded)=T1c2;
        T1C3_record(:,upgraded)=T1c3;
        T1fR1_record(:,upgraded)=T1fr1;
        T1fR2_record(:,upgraded)=T1fr2;
        T1fR3_record(:,upgraded)=T1fr3;
        
        T2CC_record(:,upgraded)=CC_mod2;
        T2P1_record(:,upgraded)=T2p1;
        T2P2_record(:,upgraded)=T2p2;
        T2P3_record(:,upgraded)=T2p3;
        T2R1_record(:,upgraded)=T2r1;
        T2R2_record(:,upgraded)=T2r2;
        T2R3_record(:,upgraded)=T2r3;
        T2C1_record(:,upgraded)=T2c1;
        T2C2_record(:,upgraded)=T2c2;
        T2C3_record(:,upgraded)=T2c3;
        T2fR1_record(:,upgraded)=T2fr1;
        T2fR2_record(:,upgraded)=T2fr2;
        T2fR3_record(:,upgraded)=T2fr3;
        J_record(:,upgraded) = J_last;
    end
    
end

%%%%%%%%%%%%%%%
%%% figures %%%
%%%%%%%%%%%%%%%

F1=figure(1); 
figure(1);plot(J_record);hold on;
saveas(F1,'Fig 1','tif');

F2=figure(2); 
% plot r1+r2+r3, r_m and r_o
T1C1_m = mean(T1C1_record');  % mean modeled respiration rate for the labile pool
T1C1_m = reshape(T1C1_m,1,Nt);
T1C2_m = mean(T1C2_record');
T1C2_m = reshape(T1C2_m,1,Nt);
T1C3_m = mean(T1C3_record');
T1C3_m = reshape(T1C3_m,1,Nt);
T1Ctot_m = sum([T1C1_m(1,:);T1C2_m(1,:);T1C3_m(1,:)]);  % total modeled respiration, equals resp_m

T2C1_m = mean(T2C1_record');  % mean modeled respiration rate for the labile pool
T2C1_m = reshape(T2C1_m,1,Nt);
T2C2_m = mean(T2C2_record');
T2C2_m = reshape(T2C2_m,1,Nt);
T2C3_m = mean(T2C3_record');
T2C3_m = reshape(T2C3_m,1,Nt);
T2Ctot_m = sum([T2C1_m(1,:);T2C2_m(1,:);T2C3_m(1,:)]);  % total modeled respiration, equals resp_m

day_d = reshape(day,1,Nt);
resp_o1 = reshape(resp1,1,Nt);
temp_d1 = reshape(temp1,1,Nt);
resp_o2 = reshape(resp2,1,Nt);
temp_d2 = reshape(temp2,1,Nt);

figure(2);subplot(1,2,1);plot(day_d(1,:),T1C1_m(1,:),'b');hold on;
figure(2);subplot(1,2,1);plot(day_d(1,:),T1C2_m(1,:),'r');hold on;
figure(2);subplot(1,2,1);plot(day_d(1,:),T1C3_m(1,:),'g');hold on;
figure(2);subplot(1,2,1);plot(day_d(1,:),T1Ctot_m(1,:),'c');hold on;
figure(2);subplot(1,2,1);plot(day_d(1,:),resp_o1(1,:),'k')
figure(2);subplot(1,2,1);xlabel('time');ylabel('Cummulative C respired (mg C g^-^1 dry soil)'); title(['25 C']);% char is for the degree symbol
figure(2);subplot(1,2,1);legend('C1','C2','C3','Cummu C_m','Cummu C_o');

figure(2);subplot(1,2,2);plot(day_d(1,:),T2C1_m(1,:),'b');hold on;
figure(2);subplot(1,2,2);plot(day_d(1,:),T2C2_m(1,:),'r');hold on;
figure(2);subplot(1,2,2);plot(day_d(1,:),T2C3_m(1,:),'g');hold on;
figure(2);subplot(1,2,2);plot(day_d(1,:),T2Ctot_m(1,:),'c');hold on;
figure(2);subplot(1,2,2);plot(day_d(1,:),resp_o2(1,:),'k')
figure(2);subplot(1,2,2);xlabel('time');ylabel('Cummulative C respired (mg C g^-^1 dry soil)'); title(['35 C']);% char is for the degree symbol
figure(2);subplot(1,2,2);legend('C1','C2','C3','Cummu C_m','Cummu C_o');

saveas(F2,'Fig 2','tif');

F3=figure(3);
F4=figure(4);
F5=figure(5);
F6=figure(6);
% parameter ranges
f1=a_upgraded(1,:);
f2=a_upgraded(2,:);
k1=b_upgraded(1,:);
k2=b_upgraded(2,:);
k3=b_upgraded(3,:);

f21=c_upgraded(1,:);
f31=c_upgraded(2,:);
f12=c_upgraded(3,:);
f32=c_upgraded(4,:);
f13=c_upgraded(5,:);

Q1=d_upgraded(1,:);
Q2=d_upgraded(2,:);
Q3=d_upgraded(3,:);

len=length(f1);
halflen=ceil(len/2);
a_1=f1(halflen:len);
a_2=f2(halflen:len);

b_1=k1(halflen:len);
b_2=k2(halflen:len);
b_3=k3(halflen:len);

c_1=f21(halflen:len);
c_2=f31(halflen:len);
c_3=f12(halflen:len);
c_4=f32(halflen:len);
c_5=f13(halflen:len);

q_1=Q1(halflen:len);
q_2=Q2(halflen:len);
q_3=Q3(halflen:len);

figure(3);subplot(1,2,1);hist(a_1,HH);title('f1');xlabel('Parameter range');ylabel('Frequency');axis([amin(1) amax(1) 1 HS]);
figure(3);subplot(1,2,2);hist(a_2,HH);title('f2');xlabel('Parameter range');ylabel('Frequency');axis([amin(2) amax(2) 1 HS]);

figure(4);subplot(1,3,1);hist(b_1,HH);title('k1');xlabel('Parameter range');ylabel('Frequency');axis([bmin(1) bmax(1) 1 HS]);
figure(4);subplot(1,3,2);hist(b_2,HH);title('k2');xlabel('Parameter range');ylabel('Frequency');axis([bmin(2) bmax(2) 1 HS]);
figure(4);subplot(1,3,3);hist(b_3,HH);title('k3');xlabel('Parameter range');ylabel('Frequency');axis([bmin(3) bmax(3) 1 HS]);

figure(5);subplot(1,5,1);hist(c_1,HH);title('f2,1');xlabel('Parameter range');ylabel('Frequency');axis([cmin(1) cmax(1) 1 HS]);
figure(5);subplot(1,5,2);hist(c_2,HH);title('f3,1');xlabel('Parameter range');ylabel('Frequency');axis([cmin(2) cmax(2) 1 HS]);
figure(5);subplot(1,5,3);hist(c_3,HH);title('f1,2');xlabel('Parameter range');ylabel('Frequency');axis([cmin(3) cmax(3) 1 HS]);
figure(5);subplot(1,5,4);hist(c_4,HH);title('f3,2');xlabel('Parameter range');ylabel('Frequency');axis([cmin(4) cmax(4) 1 HS]);
figure(5);subplot(1,5,5);hist(c_5,HH);title('f1,3');xlabel('Parameter range');ylabel('Frequency');axis([cmin(5) cmax(5) 1 HS]);

figure(6);subplot(1,3,1);hist(q_1,HH);title('Q_1_0(fast)');xlabel('Parameter range');ylabel('Frequency');axis([dmin(1) dmax(1) 1 HS]);
figure(6);subplot(1,3,2);hist(q_2,HH);title('Q_1_0(slow)');xlabel('Parameter range');ylabel('Frequency');axis([dmin(2) dmax(2) 1 HS]);
figure(6);subplot(1,3,3);hist(q_3,HH);title('Q_1_0(passive)');xlabel('Parameter range');ylabel('Frequency');axis([dmin(3) dmax(3) 1 HS]);

saveas(F3,'Fig 3','tif');
saveas(F4,'Fig 4','tif');
saveas(F5,'Fig 5','tif');
saveas(F6,'Fig 6','tif');

F7=figure(7);
%%% scatter plot of observed soil respiration versus modeled soil
%%% respiration

C_m1 = mean(T1CC_record');
C_m1 = reshape(C_m1,1,Nt);

C_m2 = mean(T2CC_record');
C_m2 = reshape(C_m2,1,Nt);
figure(7);subplot(1,2,1);plot(resp_o1(1,:),C_m1(1,:),'.');title('25 C');xlabel('Observed cummulative C');ylabel('Modeled cummulative C');refline;x1=resp_o1(1,:);y1=C_m1(1,:);R1=corrcoef(x1,y1);R_squared1=R1(2)^2;text(1, 10, ['R^2 = ' num2str(R_squared1)]);
figure(7);subplot(1,2,2);plot(resp_o2(1,:),C_m2(1,:),'.');title('35 C');xlabel('Observed cummulative C');ylabel('Modeled cummulative C');refline;x2=resp_o2(1,:);y2=C_m2(1,:);R2=corrcoef(x2,y2);R_squared2=R2(2)^2;text(1, 20, ['R^2 = ' num2str(R_squared2)]);
cor_om1 = corrcoef(resp_o1,C_m1);
cor_om2 = corrcoef(resp_o2,C_m2);      % correlation coeffecient of observed vs modeled resp
saveas(F7,'Fig 7','tif');

F8=figure(8);
% Carbon pool dynamics
T1P1_m = mean(T1P1_record'); % C-pool 1
T1P1_m = reshape(T1P1_m,1,Nt); %
T1P2_m = mean(T1P2_record'); % C-pool 2
T1P2_m = reshape(T1P2_m,1,Nt); %
T1P3_m = mean(T1P3_record'); % C-pool 3
T1P3_m = reshape(T1P3_m,1,Nt); %
T1Ptotal_m = sum([T1P1_m(1,:);T1P2_m(1,:);T1P3_m(1,:)]);     % total C-pool dynamics

T2P1_m = mean(T2P1_record'); % C-pool 1
T2P1_m = reshape(T2P1_m,1,Nt); %
T2P2_m = mean(T2P2_record'); % C-pool 2
T2P2_m = reshape(T2P2_m,1,Nt); %
T2P3_m = mean(T2P3_record'); % C-pool 3
T2P3_m = reshape(T2P3_m,1,Nt); %
T2Ptotal_m = sum([T2P1_m(1,:);T2P2_m(1,:);T2P3_m(1,:)]);

figure(8);subplot(1,2,1);plot(day_d(1,:), T1P1_m(1,:),'b');hold on; xlabel('days');ylabel('C pool dynamics mg C g-1 dry soil');title('25 C');
figure(8);subplot(1,2,1);plot(day_d(1,:), T1P2_m(1,:),'r'); hold on; 
figure(8);subplot(1,2,1);plot(day_d(1,:), T1P3_m(1,:),'g'); hold on; 
figure(8);subplot(1,2,1);plot(day_d(1,:), T1Ptotal_m(1,:),'c');
figure(8);subplot(1,2,1);legend('P1','P2','P3','Ptot');

figure(8);subplot(1,2,2);plot(day_d(1,:), T2P1_m(1,:),'b');hold on; xlabel('days');ylabel('C pool dynamics mg C g-1 dry soil');title('35 C');
figure(8);subplot(1,2,2);plot(day_d(1,:), T2P2_m(1,:),'r'); hold on; 
figure(8);subplot(1,2,2);plot(day_d(1,:), T2P3_m(1,:),'g'); hold on; 
figure(8);subplot(1,2,2);plot(day_d(1,:), T2Ptotal_m(1,:),'c');
saveas(F8,'Fig 8','tif');


F9=figure(9);
T1R1_m = mean(T1R1_record'); % respiration of pool 1
T1R1_m = reshape(T1R1_m,1,Nt); %
T1R2_m = mean(T1R2_record'); % respiration of pool 2
T1R2_m = reshape(T1R2_m,1,Nt); %
T1R3_m = mean(T1R3_record'); % respiration of pool 3
T1R3_m = reshape(T1R3_m,1,Nt); %
T1Rtotal_m = sum([T1R1_m(1,:);T1R2_m(1,:);T1R3_m(1,:)]);

T1fR1_m = mean(T1fR1_record'); % respiration of pool 1
T1fR1_m = reshape(T1fR1_m,1,Nt); %
T1fR2_m = mean(T1fR2_record'); % respiration of pool 2
T1fR2_m = reshape(T1fR2_m,1,Nt); %
T1fR3_m = mean(T1fR3_record'); % respiration of pool 3
T1fR3_m = reshape(T1fR3_m,1,Nt); %
T1fRtotal_m = sum([T1fR1_m(1,:);T1fR2_m(1,:);T1fR3_m(1,:)]);

T2R1_m = mean(T2R1_record'); % respiration of pool 1
T2R1_m = reshape(T2R1_m,1,Nt); %
T2R2_m = mean(T2R2_record'); % respiration of pool 2
T2R2_m = reshape(T2R2_m,1,Nt); %
T2R3_m = mean(T2R3_record'); % respiration of pool 3
T2R3_m = reshape(T2R3_m,1,Nt); %
T2Rtotal_m = sum([T2R1_m(1,:);T2R2_m(1,:);T2R3_m(1,:)]);

T2fR1_m = mean(T2fR1_record'); % respiration of pool 1
T2fR1_m = reshape(T2fR1_m,1,Nt); %
T2fR2_m = mean(T2fR2_record'); % respiration of pool 2
T2fR2_m = reshape(T2fR2_m,1,Nt); %
T2fR3_m = mean(T2fR3_record'); % respiration of pool 3
T2fR3_m = reshape(T2fR3_m,1,Nt); %
T2fRtotal_m = sum([T2fR1_m(1,:);T2fR2_m(1,:);T2fR3_m(1,:)]);

figure(9);subplot(2,2,1);plot(day_d(1,:),T1R1_m(1,:),'b');hold on;xlabel('days');ylabel('Respiration rate');
figure(9);subplot(2,2,1);plot(day_d(1,:),T1R2_m(1,:),'r');hold on;
figure(9);subplot(2,2,1);plot(day_d(1,:),T1R3_m(1,:),'g');hold on;
figure(9);subplot(2,2,1);plot(day_d(1,:),T1Rtotal_m(1,:),'c');hold on;
title('25 C');legend('R1','R2','R3','Rtot');

figure(9);subplot(2,2,2);plot(day_d(1,:),T1fR1_m(1,:),'b');hold on;xlabel('days');ylabel('Fractions of respired C to total respiration');
figure(9);subplot(2,2,2);plot(day_d(1,:),T1fR2_m(1,:),'r');hold on;
figure(9);subplot(2,2,2);plot(day_d(1,:),T1fR3_m(1,:),'g');hold on;
figure(9);subplot(2,2,2);plot(day_d(1,:),T1fRtotal_m(1,:),'c');hold on;
legend('fR1','fR2','fR3','fRtot');

figure(9);subplot(2,2,3);plot(day_d(1,:),T2R1_m(1,:),'b');hold on;xlabel('days');ylabel('Respiration rate');
figure(9);subplot(2,2,3);plot(day_d(1,:),T2R2_m(1,:),'r');hold on;
figure(9);subplot(2,2,3);plot(day_d(1,:),T2R3_m(1,:),'g');hold on;
figure(9);subplot(2,2,3);plot(day_d(1,:),T2Rtotal_m(1,:),'c');hold on;
title('35 C');legend('R1','R2','R3','Rtot');

figure(9);subplot(2,2,4);plot(day_d(1,:),T2fR1_m(1,:),'b');hold on;xlabel('days');ylabel('Fractions of respired C to total respiration');
figure(9);subplot(2,2,4);plot(day_d(1,:),T2fR2_m(1,:),'r');hold on;
figure(9);subplot(2,2,4);plot(day_d(1,:),T2fR3_m(1,:),'g');hold on;
figure(9);subplot(2,2,4);plot(day_d(1,:),T2fRtotal_m(1,:),'c');hold on;
legend('fR1','fR2','fR3','fRtot');

saveas(F9,'Fig 9','tif');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% write the parameters and new data into excel files %%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% % write the parameters into excel files
parameters(:,1)=a_1'; % assigns the parameters to one Matrix
parameters(:,2)=a_2';

parameters(:,3)=b_1';
parameters(:,4)=b_2';
parameters(:,5)=b_3';
parameters(:,6)=c_1';
parameters(:,7)=c_2';
parameters(:,8)=c_3';
parameters(:,9)=c_4';
parameters(:,10)=c_5';
parameters(:,11)=q_1';
parameters(:,12)=q_2';
parameters(:,13)=q_3';

fid1=fopen('param.csv','wt');
fprintf(fid1,'%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s\n','f1','f2','T1k1','T1k2','T1k3','f21','f31','f12','f32','f13','Q10(fast)','Q10(slow)','Q10(passive)');
[rows,cols]=size(parameters);

for i=1:rows
    for j=1:cols
        if(j<cols)
        fprintf(fid1,'%f,',parameters(i,j));
        else
        fprintf(fid1,'%f\n',parameters(i,j));
        end
    end
    %fprintf(fid1,'%f\n',parameters(i,j));
end

fclose(fid1);

% write resp_mod to excel
dat_m(:,1)=day_d(1,:); 
dat_m(:,2)= temp_d1(1,:);

dat_m(:,3)=T1P1_m(1,:);    
dat_m(:,4)=T1P2_m(1,:);
dat_m(:,5)=T1P3_m(1,:);

dat_m(:,6)=T1R1_m(1,:);
dat_m(:,7)=T1R2_m(1,:);
dat_m(:,8)=T1R3_m(1,:);

dat_m(:,9)=T1fR1_m(1,:);
dat_m(:,10)=T1fR2_m(1,:);
dat_m(:,11)=T1fR3_m(1,:);

dat_m(:,12)=T1C1_m(1,:);
dat_m(:,13)=T1C2_m(1,:);
dat_m(:,14)=T1C3_m(1,:);

dat_m(:,15)=T1Ctot_m(1,:);
dat_m(:,16)=resp_o1(1,:);


dat_n(:,1)=day_d(1,:); 
dat_n(:,2)= temp_d2(1,:);

dat_n(:,3)=T2P1_m(1,:);    
dat_n(:,4)=T2P2_m(1,:);
dat_n(:,5)=T2P3_m(1,:);

dat_n(:,6)=T2R1_m(1,:);
dat_n(:,7)=T2R2_m(1,:);
dat_n(:,8)=T2R3_m(1,:);

dat_n(:,9)=T2fR1_m(1,:);
dat_n(:,10)=T2fR2_m(1,:);
dat_n(:,11)=T2fR3_m(1,:);

dat_n(:,12)=T2C1_m(1,:);
dat_n(:,13)=T2C2_m(1,:);
dat_n(:,14)=T2C3_m(1,:);

dat_n(:,15)=T2Ctot_m(1,:);
dat_n(:,16)=resp_o2(1,:);

fid2=fopen('resp_25.csv','wt');
fprintf(fid2,'%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s\n','day','temp','P1_m','P2_m','P3_m','R1_m','R2_m','R3_m','fR1_m','fR2_m','fR3_m','C1_m','C2_m','C3_m','Ctot_m','Ctot_o');
[rows,cols]=size(dat_m);

for i=1:rows
    for j=1:cols
        if(j<cols)
        fprintf(fid2,'%f,',dat_m(i,j));
        else
        fprintf(fid2,'%f\n',dat_m(i,j));
        end
    end
    
end

fclose(fid2);

fid3=fopen('resp_35.csv','wt');
fprintf(fid3,'%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s\n','day','temp','P1_m','P2_m','P3_m','R1_m','R2_m','R3_m','fR1_m','fR2_m','fR3_m','C1_m','C2_m','C3_m','Ctot_m','Ctot_o');
[rows,cols]=size(dat_n);

for i=1:rows
    for j=1:cols
        if(j<cols)
        fprintf(fid3,'%f,',dat_n(i,j));
        else
        fprintf(fid3,'%f\n',dat_n(i,j));
        end
    end
    
end

fclose(fid3);

%%%The End
